==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/insights/kotlin/inputs/VoiceReceiverArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.insights.kotlin.inputs

import com.pulumi.azurenative.insights.inputs.VoiceReceiverArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * A voice receiver.
 * @property countryCode The country code of the voice receiver.
 * @property name The name of the voice receiver. Names must be unique across all receivers within a tenant action group.
 * @property phoneNumber The phone number of the voice receiver.
 */
public data class VoiceReceiverArgs(
    public val countryCode: Output<String>,
    public val name: Output<String>,
    public val phoneNumber: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.insights.inputs.VoiceReceiverArgs> {
    override fun toJava(): com.pulumi.azurenative.insights.inputs.VoiceReceiverArgs =
        com.pulumi.azurenative.insights.inputs.VoiceReceiverArgs.builder()
            .countryCode(countryCode.applyValue({ args0 -> args0 }))
            .name(name.applyValue({ args0 -> args0 }))
            .phoneNumber(phoneNumber.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VoiceReceiverArgs].
 */
@PulumiTagMarker
public class VoiceReceiverArgsBuilder internal constructor() {
    private var countryCode: Output<String>? = null

    private var name: Output<String>? = null

    private var phoneNumber: Output<String>? = null

    /**
     * @param value The country code of the voice receiver.
     */
    @JvmName("uubrbcnplxyqxmth")
    public suspend fun countryCode(`value`: Output<String>) {
        this.countryCode = value
    }

    /**
     * @param value The name of the voice receiver. Names must be unique across all receivers within a tenant action group.
     */
    @JvmName("myjuggviylvwilci")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The phone number of the voice receiver.
     */
    @JvmName("howpjrrdhsbxujnj")
    public suspend fun phoneNumber(`value`: Output<String>) {
        this.phoneNumber = value
    }

    /**
     * @param value The country code of the voice receiver.
     */
    @JvmName("qwbtgtpyrmpxcocl")
    public suspend fun countryCode(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.countryCode = mapped
    }

    /**
     * @param value The name of the voice receiver. Names must be unique across all receivers within a tenant action group.
     */
    @JvmName("cfjrjotckwfgqusw")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The phone number of the voice receiver.
     */
    @JvmName("ygmnvqgiqcviplnc")
    public suspend fun phoneNumber(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.phoneNumber = mapped
    }

    internal fun build(): VoiceReceiverArgs = VoiceReceiverArgs(
        countryCode = countryCode ?: throw PulumiNullFieldException("countryCode"),
        name = name ?: throw PulumiNullFieldException("name"),
        phoneNumber = phoneNumber ?: throw PulumiNullFieldException("phoneNumber"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/insights/kotlin/inputs/VoiceReceiverArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.insights.kotlin.inputs

import com.pulumi.azurenative.insights.inputs.VoiceReceiverArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * A voice receiver.
 * @property countryCode The country code of the voice receiver.
 * @property name The name of the voice receiver. Names must be unique across all receivers within a tenant action group.
 * @property phoneNumber The phone number of the voice receiver.
 */
public data class VoiceReceiverArgs(
    public val countryCode: Output<String>,
    public val name: Output<String>,
    public val phoneNumber: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.insights.inputs.VoiceReceiverArgs> {
    override fun toJava(): com.pulumi.azurenative.insights.inputs.VoiceReceiverArgs =
        com.pulumi.azurenative.insights.inputs.VoiceReceiverArgs.builder()
            .countryCode(countryCode.applyValue({ args0 -> args0 }))
            .name(name.applyValue({ args0 -> args0 }))
            .phoneNumber(phoneNumber.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VoiceReceiverArgs].
 */
@PulumiTagMarker
public class VoiceReceiverArgsBuilder internal constructor() {
    private var countryCode: Output<String>? = null

    private var name: Output<String>? = null

    private var phoneNumber: Output<String>? = null

    /**
     * @param value The country code of the voice receiver.
     */
    @JvmName("asepxigxevmpgaqh")
    public suspend fun countryCode(`value`: Output<String>) {
        this.countryCode = value
    }

    /**
     * @param value The name of the voice receiver. Names must be unique across all receivers within a tenant action group.
     */
    @JvmName("anmqducojoeboyrg")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The phone number of the voice receiver.
     */
    @JvmName("wmdyjhtvrqawusiv")
    public suspend fun phoneNumber(`value`: Output<String>) {
        this.phoneNumber = value
    }

    /**
     * @param value The country code of the voice receiver.
     */
    @JvmName("htnnucxemlacggvn")
    public suspend fun countryCode(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.countryCode = mapped
    }

    /**
     * @param value The name of the voice receiver. Names must be unique across all receivers within a tenant action group.
     */
    @JvmName("laktinvmshbxcikl")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The phone number of the voice receiver.
     */
    @JvmName("dqpqrqyyjusftqba")
    public suspend fun phoneNumber(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.phoneNumber = mapped
    }

    internal fun build(): VoiceReceiverArgs = VoiceReceiverArgs(
        countryCode = countryCode ?: throw PulumiNullFieldException("countryCode"),
        name = name ?: throw PulumiNullFieldException("name"),
        phoneNumber = phoneNumber ?: throw PulumiNullFieldException("phoneNumber"),
    )
}
